mpl\_toolkits.mplot3d.axes3d.Axes3D
===================================


.. currentmodule:: mpl_toolkits.mplot3d.axes3d


.. autoclass:: Axes3D
   :no-members:
   :no-undoc-members:
   :show-inheritance:


.. currentmodule:: mpl_toolkits.mplot3d.axes3d.Axes3D


Plotting
--------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   plot
   scatter
   bar
   bar3d

   plot_surface
   plot_wireframe
   plot_trisurf
   fill_between

   clabel
   contour
   tricontour
   contourf
   tricontourf

   quiver
   voxels
   errorbar
   stem


Text and annotations
--------------------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   text
   text2D


Clearing
--------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   clear


Appearance
----------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   set_axis_off
   set_axis_on
   grid


Axis
----

Axis limits and direction
^^^^^^^^^^^^^^^^^^^^^^^^^

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   get_zaxis
   get_xlim
   set_xlim
   get_ylim
   set_ylim
   get_zlim
   set_zlim
   get_w_lims
   invert_xaxis
   xaxis_inverted
   invert_yaxis
   yaxis_inverted
   invert_zaxis
   zaxis_inverted
   get_xbound
   set_xbound
   get_ybound
   set_ybound
   get_zbound
   set_zbound


Axis labels and title
^^^^^^^^^^^^^^^^^^^^^

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   set_zlabel
   get_zlabel
   set_title


Axis scales
^^^^^^^^^^^

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   set_xscale
   set_yscale
   set_zscale
   get_zscale


Autoscaling and margins
^^^^^^^^^^^^^^^^^^^^^^^

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   get_zmargin
   set_zmargin
   margins
   autoscale
   autoscale_view
   set_autoscalez_on
   get_autoscalez_on
   auto_scale_xyz


Aspect ratio
^^^^^^^^^^^^

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   set_aspect
   set_box_aspect
   apply_aspect


Ticks
^^^^^

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   tick_params
   set_zticks
   get_zticks
   set_zticklabels
   get_zticklines
   get_zgridlines
   get_zminorticklabels
   get_zmajorticklabels
   zaxis_date


Units
-----

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   convert_zunits


Adding artists
--------------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   add_collection3d


Sharing
-------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   sharez
   shareview


Interactive
-----------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   can_zoom
   can_pan
   disable_mouse_rotation
   mouse_init
   drag_pan
   format_zdata
   format_coord


Projection and perspective
--------------------------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   view_init
   set_proj_type
   get_proj
   set_top_view


Drawing
-------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   draw
   get_tightbbox


Aliases and deprecated methods
------------------------------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

    set_zlim3d
    stem3D
    text3D


Other
-----

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   get_axis_position
   add_contour_set
   add_contourf_set
   update_datalim


.. currentmodule:: mpl_toolkits.mplot3d

Sample 3D data
--------------

.. autosummary::
   :toctree: ../../_as_gen
   :template: autosummary.rst
   :nosignatures:

   axes3d.get_test_data


.. minigallery:: mpl_toolkits.mplot3d.axes3d.Axes3D
   :add-heading:
